# Roadmap

Where do we go from here? What are the project's priorities?

## 1. Tests and docs coverage

Every method should have a good docstring with an example.

Test coverage should be 100%.

CI should test across a variety of pandas and Polars versions.

## 2. API coverage

Narwhals should be complete enough to be able to execute all the tpc-h queries.

## 3. Other backends?

Can we translate Narwhals to SQL / substrait and support, say, DuckDB?

## 4. Query optimisation

Can we insert a light layer to do some simple query optimisation for pandas?
